@@ -1,6 +1,6 @@
 ######################################################################
 #
-# Copyright 2001-2008 by Wilson Snyder.  This program is free software;
+# Copyright 2001-2009 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
 #
@@ -22,7 +22,7 @@ use base qw(DynaLoader);
 use strict;
 use vars qw($VERSION $Debug);
 
-$VERSION = '3.045';
+$VERSION = '3.100';
 
 #$Debug sets the default value for debug.  You're better off with the object method though.
 
@@ -417,7 +417,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2008 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2009 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License or the Perl Artistic License.
 
@@ -434,7 +434,7 @@ L<Verilog::Language>,
 L<Verilog::Netlist>,
 L<Verilog::Getopt>,
 L<vrename>,
-L<vpm>
-L<vppp>
+L<vpassert>
+L<vppreproc>
 
 =cut
